#include "testApp.h"


//--------------------------------------------------------------
void testApp::setup(){	
	
	ofSetVerticalSync(true);
	ofSetFrameRate(60);
	
	for (int i = 0; i < 200; i++){
		particle myParticle;
		myParticle.setInitialCondition(ofRandom(10,1000),ofRandom(0,ofGetHeight()),0,0);
		particles.push_back(myParticle);
	}
	
	VF.setupField(60,40,ofGetWidth(), ofGetHeight());
	VF.randomizeField(2.0);
	bParticlesRepel = true;
	bFade = false;
}

//--------------------------------------------------------------
void testApp::update(){

	// on every frame 
	// we reset the forces
	// add in any forces on the particle
	// perfom damping and
	// then update
	
	
	ofBackground(255,255,255);	
	counter += 1.0f;
	
	for (int i = 0; i < particles.size(); i++){
		particles[i].resetForce();
		
		// get the force from the vector field: 
		ofxVec2f frc;
		frc = VF.getForceFromPos(particles[i].pos.x, particles[i].pos.y);
		particles[i].addForce(frc.x, frc.y);
		
		if (bParticlesRepel == true){
			for (int j = 0; j < i; j++){
				particles[i].addRepulsionForce(particles[j], 50, 0.2);
			}
		}
		
		particles[i].addForce(0,0.4f);
		particles[i].addDampingForce();
		particles[i].update();
		
		if (particles[i].pos.y > ofGetHeight()){
			particles[i].pos.x = ofRandom(10,1000);
			particles[i].pos.y = 0;

		}
	}
	
	
	if (bFade == true) VF.fadeField(0.99f);

}

//--------------------------------------------------------------
void testApp::draw(){
	

	ofEnableAlphaBlending();
	VF.draw();
	
	ofSetColor(250,130,130, 200);
	
	for (int i = 0; i < particles.size(); i++){
		particles[i].draw();
	}
	
	ofDrawBitmapString("hallelujah", ofGetWidth()/2-50, ofGetHeight()/2);

	
}

//--------------------------------------------------------------
void testApp::keyPressed  (int key){ 
	
	if (key == ' '){
		VF.clear();
	} else if (key == 'f'){
		bFade = !bFade;
	} else if (key == 'r'){
		bParticlesRepel = !bParticlesRepel;
	}
}	

//--------------------------------------------------------------
void testApp::keyReleased  (int key){ 
}

//--------------------------------------------------------------
void testApp::mouseMoved(int x, int y ){
}

//--------------------------------------------------------------
void testApp::mouseDragged(int x, int y, int button){
	if (button == 0) {
		VF.addOutwardCircle((float)x, (float)y, 100, 0.29f);
	} else {
		
		particles.erase(particles.begin());
		particle myParticle;
		myParticle.setInitialCondition(x,y,0,0);
		particles.push_back(myParticle);
		
		
	}
}

//--------------------------------------------------------------
void testApp::mousePressed(int x, int y, int button){
}

//--------------------------------------------------------------
void testApp::mouseReleased(){
}
